@@ -1,11 +1,9 @@
 import re
-import ujson
-import redis
 import user_agents
-
 from datetime import datetime
 
 from cytra.auth import Authenticator
+from cytra import json
 
 
 class StatefulAuthenticator(Authenticator):
@@ -104,7 +102,7 @@ class StatefulAuthenticator(Authenticator):
     def update_session_info(self, session_id):
         self.redis.set(
             self.get_session_info_key(session_id),
-            ujson.dumps(self.extract_session_info()),
+            json.dumps(self.extract_session_info()),
         )
 
     def register_session(self, member_id, session_id):
@@ -112,7 +110,7 @@ class StatefulAuthenticator(Authenticator):
         self.redis.sadd(self.get_member_sessions_key(member_id), session_id)
         self.redis.set(
             self.get_session_info_key(session_id),
-            ujson.dumps(self.extract_session_info()),
+            json.dumps(self.extract_session_info()),
         )
 
     def unregister_session(self, session_id=None):
@@ -159,5 +157,5 @@ class StatefulAuthenticator(Authenticator):
     def get_session_info(self, session_id):
         info = self.redis.get(self.get_session_info_key(session_id))
         if info:
-            return ujson.loads(info)
+            return json.loads(info)
         return None
