@@ -9,23 +9,23 @@ from cytra.db.access_control_mixin import AccessControlMixin
 class SerializeMixin(TransformMixin, AccessControlMixin):
     def to_dict(self) -> dict:
         result = dict()
-        for type_, key, info, c in self.__class__.get_readables(self.__app__):
-            key = self.get_column_key(c)
+        for ic in self.__class__.get_readables(self):
+            key = self.get_column_key(ic.column)
             result.setdefault(
-                self.export_column_name(key, info),
-                self.export_value(c, getattr(self, key)),
+                self.export_column_name(key, ic.info),
+                self.export_value(ic.column, getattr(self, key)),
             )
         return result
 
     def update_from_dict(self, data: dict) -> None:
         datakeys = data.keys()
-        for type_, key, info, c in self.get_writables(self.__app__):
-            key = self.get_column_key(c)
-            key_ = self.export_column_name(key, info)
+        for ic in self.__class__.get_writables(self):
+            key = self.get_column_key(ic.column)
+            key_ = self.export_column_name(key, ic.info)
             if key_ not in datakeys:
                 continue
 
-            setattr(self, key, self.import_value(c, data[key_]))
+            setattr(self, key, self.import_value(ic.column, data[key_]))
 
     def update_from_request(self) -> None:
         self.update_from_dict(self.__app__.request.form)
